from setuptools import setup

setup(
    name='Crabsnack',
    version='0.1',
    description='The best sea food in the world',
    include_package_data=True,
    url='http://github.com/victorziv/crabsnack',
    author='Flying Circus',
    author_email='flyingcircus@example.com',
    license='MIT',
    packages=['crabsnack'],
    zip_safe=False
)
